@@ -11,7 +11,7 @@ def send_email(sender, instance, **kwargs):
     #
     # return if we're in silent mode return
     try:
-        if instance.slient == True:
+        if instance.silent:
             return
     except AttributeError:
         pass
